@@ -12,6 +12,7 @@
 
 namespace Composer\Console;
 
+use Composer\Installer;
 use Composer\IO\NullIO;
 use Composer\Util\Filesystem;
 use Composer\Util\Platform;
@@ -32,6 +33,7 @@ use Seld\JsonLint\ParsingException;
 use Composer\Command;
 use Composer\Composer;
 use Composer\Factory;
+use Composer\Downloader\TransportException;
 use Composer\IO\IOInterface;
 use Composer\IO\ConsoleIO;
 use Composer\Json\JsonValidationException;
@@ -41,6 +43,7 @@ use Composer\EventDispatcher\ScriptExecutionException;
 use Composer\Exception\NoSslException;
 use Composer\XdebugHandler\XdebugHandler;
 use Symfony\Component\Process\Exception\ProcessTimedOutException;
+use Composer\Util\Http\ProxyManager;
 
 /**
  * The console application that handles the commands
@@ -215,7 +218,11 @@ class Application extends BaseApplication
         $needsSudoCheck = !Platform::isWindows()
             && function_exists('exec')
             && !Platform::getEnv('COMPOSER_ALLOW_SUPERUSER')
-            && (ini_get('open_basedir') || !file_exists('/.dockerenv'));
+            && (ini_get('open_basedir') || (
+                !file_exists('/.dockerenv')
+                && !file_exists('/run/.containerenv')
+                && !file_exists('/var/run/.containerenv')
+            ));
         $isNonAllowedRoot = false;
 
         // Clobber sudo credentials if COMPOSER_ALLOW_SUPERUSER is not set before loading plugins
@@ -293,7 +300,8 @@ class Application extends BaseApplication
         }
 
         if (!$this->disablePluginsByDefault && $isNonAllowedRoot && !$io->isInteractive()) {
-            $io->writeError('<error>Composer plugins have been disabled for safety in this non-interactive session. Set COMPOSER_ALLOW_SUPERUSER=1 if you want to allow plugins to run as root/super user.</error>');
+            $io->writeError('<error>Composer plugins have been disabled for safety in this non-interactive session.</error>');
+            $io->writeError('<error>Set COMPOSER_ALLOW_SUPERUSER=1 if you want to allow plugins to run as root/super user.</error>');
             $this->disablePluginsByDefault = true;
         }
 
@@ -376,6 +384,8 @@ class Application extends BaseApplication
         }
 
         try {
+            $proxyManager = ProxyManager::getInstance();
+
             if ($input->hasParameterOption('--profile')) {
                 $startTime = microtime(true);
                 $this->io->enableDebugging($startTime);
@@ -383,6 +393,11 @@ class Application extends BaseApplication
 
             $result = parent::doRun($input, $output);
 
+            if (true === $input->hasParameterOption(['--version', '-V'], true)) {
+                $io->writeError(sprintf('<info>PHP</info> version <comment>%s</comment> (%s)', \PHP_VERSION, \PHP_BINARY));
+                $io->writeError('Run the "diagnose" command to get more detailed diagnostics output.');
+            }
+
             // chdir back to $oldWorkingDir if set
             if (isset($oldWorkingDir) && '' !== $oldWorkingDir) {
                 Silencer::call('chdir', $oldWorkingDir);
@@ -392,6 +407,14 @@ class Application extends BaseApplication
                 $io->writeError('<info>Memory usage: '.round(memory_get_usage() / 1024 / 1024, 2).'MiB (peak: '.round(memory_get_peak_usage() / 1024 / 1024, 2).'MiB), time: '.round(microtime(true) - $startTime, 2).'s');
             }
 
+            if ($proxyManager->needsTransitionWarning()) {
+                $io->writeError('');
+                $io->writeError('<warning>Composer now requires separate proxy environment variables for HTTP and HTTPS requests.</warning>');
+                $io->writeError('<warning>Please set `https_proxy` in addition to your existing proxy environment variables.</warning>');
+                $io->writeError('<warning>This fallback (and warning) will be removed in Composer 2.8.0.</warning>');
+                $io->writeError('<warning>https://getcomposer.org/doc/faqs/how-to-use-composer-behind-a-proxy.md</warning>');
+            }
+
             return $result;
         } catch (ScriptExecutionException $e) {
             if ($this->getDisablePluginsByDefault() && $this->isRunningAsRoot() && !$this->io->isInteractive()) {
@@ -419,6 +442,13 @@ class Application extends BaseApplication
                 return max(1, $e->getCode());
             }
 
+            // override TransportException's code for the purpose of parent::run() using it as process exit code
+            // as http error codes are all beyond the 255 range of permitted exit codes
+            if ($e instanceof TransportException) {
+                $reflProp = new \ReflectionProperty($e, 'code');
+                $reflProp->setValue($e, Installer::ERROR_TRANSPORT_EXCEPTION);
+            }
+
             throw $e;
         } finally {
             restore_error_handler();
@@ -466,6 +496,11 @@ class Application extends BaseApplication
         }
         Silencer::restore();
 
+        if ($exception instanceof TransportException && str_contains($exception->getMessage(), 'Unable to use a proxy')) {
+            $io->writeError('<error>The following exception indicates your proxy is misconfigured</error>', true, IOInterface::QUIET);
+            $io->writeError('<error>Check https://getcomposer.org/doc/faqs/how-to-use-composer-behind-a-proxy.md for details</error>', true, IOInterface::QUIET);
+        }
+
         if (Platform::isWindows() && false !== strpos($exception->getMessage(), 'The system cannot find the path specified')) {
             $io->writeError('<error>The following exception may be caused by a stale entry in your cmd.exe AutoRun</error>', true, IOInterface::QUIET);
             $io->writeError('<error>Check https://getcomposer.org/doc/articles/troubleshooting.md#-the-system-cannot-find-the-path-specified-windows- for details</error>', true, IOInterface::QUIET);
